@@ -7,10 +7,11 @@
     version 2 of the License, or (at your option) any later version.
  */
 
+#include "ekosmanager.h"
+
 #include <basedevice.h>
 
 #include "Options.h"
-#include "ekosmanager.h"
 #include "kstars.h"
 
 #include <KMessageBox>
@@ -510,18 +511,32 @@ void EkosManager::connectDevices()
          scope->Connect();
 
     if (ccd)
+    {
         ccd->Connect();
 
+        if (captureProcess)
+            captureProcess->setEnabled(true);
+    }
+
 
     if (guider && guider != ccd)
         guider->Connect();
 
+    if (guider && guideProcess)
+        guideProcess->setEnabled(true);
+
     if (filter && filter != ccd)
         filter->Connect();
 
     if (focuser)
+    {
         focuser->Connect();
 
+        if (focusProcess)
+            focusProcess->setEnabled(true);
+    }
+
+
     if (aux)
         aux->Connect();
 
@@ -541,18 +556,32 @@ void EkosManager::disconnectDevices()
     {
         ccdStarted      =false;
         ccd->Disconnect();
+
+        if (captureProcess)
+            captureProcess->setEnabled(false);
+
     }
 
     if (guider && guider != ccd)
         guider->Disconnect();
 
+    if (guider && guideProcess)
+        guideProcess->setEnabled(false);
 
     if (filter && filter != ccd)
         filter->Disconnect();
 
     if (focuser)
+    {
         focuser->Disconnect();
 
+        if (focusProcess)
+        {
+            disconnect(focuser, SIGNAL(numberUpdated(INumberVectorProperty*)), focusProcess, SLOT(processFocusProperties(INumberVectorProperty*)));
+            focusProcess->setEnabled(false);
+        }
+     }
+
     if (aux)
         aux->Disconnect();
 
@@ -920,7 +949,10 @@ void EkosManager::processNewProperty(INDI::Property* prop)
     if (!strcmp(prop->getName(), "TELESCOPE_INFO"))
     {
         if (guideProcess)
+        {
+           guideProcess->setTelescope(scope);
            guideProcess->syncTelescopeInfo();
+        }
 
     }
 
